/*
    Rosegarden
    A MIDI and audio sequencer and musical notation editor.

    This program is Copyright 2000-2008
        Guillaume Laurent   <glaurent@telegraph-road.org>,
        Chris Cannam        <cannam@all-day-breakfast.com>,
        Richard Bown        <richard.bown@ferventsoftware.com>

    The moral rights of Guillaume Laurent, Chris Cannam, and Richard
    Bown to claim authorship of this work have been asserted.

    Other copyrights also apply to some parts of this work.  Please
    see the AUTHORS file and individual file headers for details.

    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License as
    published by the Free Software Foundation; either version 2 of the
    License, or (at your option) any later version.  See the file
    COPYING included with this distribution for more information.
*/

#ifndef _RG_INTERPRETDIALOG_H_
#define _RG_INTERPRETDIALOG_H_

#include <kdialogbase.h>


class TQWidget;
class TQCheckBox;


namespace Rosegarden
{



class InterpretDialog : public KDialogBase
{
    TQ_OBJECT
  
public:
    InterpretDialog(TQWidget *parent);

    // an OR from InterpretCommand's constants
    int getInterpretations();

protected slots:
    void slotAllBoxChanged();

private:
    TQCheckBox *m_allInterpretations;
    TQCheckBox *m_applyTextDynamics;
    TQCheckBox *m_applyHairpins;
    TQCheckBox *m_stressBeats;
    TQCheckBox *m_articulate;
};



}

#endif
